@@ -1,5 +1,5 @@
 # pylint: disable=cyclic-import
-from typing import TYPE_CHECKING, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Dict, List, Optional
 from uuid import UUID
 
 # Override Bandit warnings, since we use this to generate XML, not parse
@@ -74,7 +74,7 @@ class Channel:
         offset: int = 0,
         include_content: bool = False,
         status: Optional[List[str]] = None,
-        params: Optional[Dict[str, Union[List[str], str, int]]] = None,
+        params: Optional[Dict] = None,
     ) -> List[ChannelMessageModel]:
         """Get a list of messages handled by the channel
 
@@ -108,6 +108,40 @@ class Channel:
         )
         return messages.message
 
+    async def preview_message(
+        self, id_: str, params: Optional[Dict] = None
+    ) -> Optional[ChannelMessageModel]:
+        """Get a minimal representation of a channel message by ID
+
+        Args:
+            id_ (str): Message ID
+            include_content (bool, optional): Include message content in response. Defaults to True.
+
+        Returns:
+            Optional[ChannelMessageModel]: Channel message object
+        """
+        params = params or {}
+        params.update(
+            {
+                "minMessageId": str(id_),
+                "maxMessageId": str(id_),
+                "includeContent": False,
+                "offset": 0,
+                "limit": 1,
+            }
+        )
+
+        response = await self.mirth.get(f"/channels/{self.id}/messages", params=params)
+
+        if response.text == "<list/>":
+            return None
+        messages = ChannelMessageList.parse_raw(
+            response.text, content_type="xml", force_list=("message", "entry")
+        )
+        if len(messages.message) < 1:
+            return None
+        return messages.message[0]
+
     async def get_message(
         self, id_: str, include_content: bool = True
     ) -> Optional[ChannelMessageModel]:
